.. _settings:

.. module:: pulsar.utils.config

====================
Settings
====================

This is the autogenerated full list of :ref:`pulsar settings <api-config>`
available for configuring your pulsar servers or applications. Pulsar can
run several :class:`.Application` in one server, via the
:class:`.MultiApp` class.

Each application has its own set of configuration parameters with the
only exception of the
:ref:`global server settings <setting-section-global-server-settings>`.


.. pulsar_settings::

Utilities
==============

.. autofunction:: pass_through
